@@ -15,6 +15,11 @@
 #
 #============================================================================================
 
+from __future__ import division
+from __future__ import print_function
+from __future__ import absolute_import
+from builtins import object
+from past.utils import old_div
 import sys
 import numpy
 import os
@@ -79,7 +84,11 @@ from pmagpy.mapping import map_magic
 
 class PintPars(object):
     """ __init__(self, Data,specimen_name,tmin,tmax,mapping=None, calculate=None)"""
-    def __init__(self, Data, specimen_name, tmin, tmax, mapping=None, calculate=None):
+    def __init__(self, Data, specimen_name, tmin=None, tmax=None,
+                 mapping=None, calculate=None,acceptance_criteria={},
+                 tmin_ind=None, tmax_ind=None):
+        #print("MAKING PINTPARS")
+        self.acceptance_criteria=acceptance_criteria
         self.s = specimen_name
         self.mapping = mapping
         ####
@@ -91,7 +100,7 @@ class PintPars(object):
                     new_stat = map_magic.spd[ind]
                     self.calculate.append(new_stat)
                 except ValueError:
-                    print 'doesn\'t start with \'specimen\'', stat
+                    print("doesn't start with 'specimen'", stat)
                     #self.calculate.append(stat)
         ####
         self.specimen_Data = Data[self.s]
@@ -138,8 +147,22 @@ class PintPars(object):
         self.zijdblock=self.specimen_Data['zijdblock']
         self.z_temperatures=self.specimen_Data['z_temp']
 
-        self.start=self.t_Arai.index(tmin)
-        self.end=self.t_Arai.index(tmax)
+
+        # find index from start/end temperatures
+        if tmin:
+            self.start=self.t_Arai.index(tmin)
+            self.end=self.t_Arai.index(tmax)
+        # or find start/end temperatures from index
+        else:
+            if not tmin_ind:tmin_ind=0
+            if not tmax_ind:tmax_ind=len(self.t_Arai)
+            self.start = tmin_ind
+            self.end = tmax_ind
+            tmin = self.t_Arai[tmin_ind]
+            try:
+                tmax = self.t_Arai[tmax_ind]
+            except IndexError:
+                tmax = self.t_Arai[-1]
 
         self.pars={}
 
@@ -185,7 +208,7 @@ class PintPars(object):
 
     def York_Regression(self):
         if self.n < 3:
-            print "-W- Cannot run statistics with only {} points".format(self.n)
+            print("-W- Cannot run statistics with only {} points".format(self.n))
             return None
         x_segment, y_segment = self.x_Arai_segment, self.y_Arai_segment
         x_mean, y_mean = self.x_Arai_mean, self.y_Arai_mean
@@ -271,7 +294,10 @@ class PintPars(object):
         slope = self.pars['specimen_b']
         x_mean, y_mean = self.x_Arai_mean, self.y_Arai_mean
         x_Arai_segment, y_Arai_segment = self.x_Arai_segment, self.y_Arai_segment
-        box = lib_arai.get_SCAT_box(slope, x_mean, y_mean)
+        if 'specimen_b_beta' in self.acceptance_criteria:
+            box = lib_arai.get_SCAT_box(slope, x_mean, y_mean, beta_threshold=self.acceptance_criteria['specimen_b_beta']['value'])
+        else:
+            box = lib_arai.get_SCAT_box(slope, x_mean, y_mean)
         low_bound, high_bound, x_max, y_max, low_line, high_line = box[0], box[1], box[2], box[3], box[4], box[5]
         # getting SCAT points
         x_Arai_segment, y_Arai_segment = self.x_Arai_segment, self.y_Arai_segment
@@ -288,7 +314,12 @@ class PintPars(object):
         SCAT = lib_arai.get_SCAT(points, low_bound, high_bound, x_max, y_max)
         fancy_SCAT, SCATs = lib_arai.fancy_SCAT(fancy_points, low_bound, high_bound, x_max, y_max)
         #'SCAT_arai': False, 'SCAT_tail': True, 'SCAT_ptrm': True})
-        self.pars['SCAT'] = fancy_SCAT
+        if fancy_SCAT.upper() == 'PASS':
+            self.pars['SCAT'] = 't'
+        else:
+            self.pars['SCAT'] = 'f'
+        #self.pars['SCAT'] = fancy_SCAT
+        # set self.pars['SCAT'] to 'g' or 'b' here?
         self.pars['fail_arai_beta_box_scatter'] = SCATs['SCAT_arai']
         self.pars["fail_ptrm_beta_box_scatter"] = SCATs['SCAT_ptrm']
         self.pars["fail_tail_beta_box_scatter"] = SCATs['SCAT_tail']
@@ -329,7 +360,7 @@ class PintPars(object):
         return Zstar
 
     def get_IZZI_MD(self):
-        import lib.lib_IZZI_MD as lib_izzi
+        import SPD.lib.lib_IZZI_MD as lib_izzi
         if ('IZ' in self.steps_Arai):
             IZZI_MD = lib_izzi.get_IZZI_MD(self.x_Arai, self.y_Arai, self.steps_Arai, self.start, self.end)
             self.pars['IZZI_MD'] = IZZI_MD
@@ -412,7 +443,7 @@ class PintPars(object):
     def get_gamma(self):
         B_lab_dir = [self.B_lab_dir[0], self.B_lab_dir[1], 1.]
         ind = self.t_Arai.index(self.tmax)
-        ptrm_dir = [self.PTRMS[ind][1], self.PTRMS[ind][2], self.PTRMS[ind][3] / self.specimen_Data['NRM']]
+        ptrm_dir = [self.PTRMS[ind][1], self.PTRMS[ind][2], old_div(self.PTRMS[ind][3], self.specimen_Data['NRM'])]
         ptrm_cart = lib_direct.dir2cart(ptrm_dir)
         gamma = lib_direct.get_gamma(B_lab_dir, ptrm_dir)
         self.pars['ptrm_dir'] = ptrm_dir
@@ -429,6 +460,7 @@ class PintPars(object):
         n, steps = lib_ptrm.get_n_ptrm(tmin, tmax, ptrm_temps, ptrm_starting_temps)
         self.pars['n_ptrm'] = n
         self.pars['ptrm_checks_included_temps'] = steps
+        return n, steps
 
     def get_max_ptrm_check(self):
         ptrm_checks_included_temps = self.pars['ptrm_checks_included_temps']
@@ -493,6 +525,9 @@ class PintPars(object):
         self.pars['mean_DEV_prime'] = mean_DEV_prime
 
     def get_delta_pal(self):
+        if not 'n_ptrm' in self.pars:
+            self.pars['delta_pal'] = 0
+            return 0
         if self.pars['n_ptrm'] == 0: # otherwise will error if no ptrm checks
             self.pars['delta_pal'] = 0
             return 0
@@ -568,7 +603,7 @@ class PintPars(object):
     def calculate_all_statistics(self):
         #print "calling calculate_all_statistics in spd.py"
         if self.n < 3:
-            print "-W- Cannot run statistics with only {} points".format(self.n)
+            print("-W- Cannot run statistics with only {} points".format(self.n))
             self.pars = {}
             return None
         self.York_Regression()
@@ -729,11 +764,13 @@ class PintPars(object):
     def reqd_stats(self):
         #print 'do REQD STATS'
         if self.n < 3:
-            print "-W- Cannot run statistics with only {} points".format(self.n)
+            print("-W- Cannot run statistics with only {} points".format(self.n))
             self.pars = {}
             return None
         stats_run = []
         #print 'self.calculate: ', self.calculate
+        if 'best_fit_vector_Free' not in self.calculate:
+            self.calculate.append('best_fit_vector_Free')
         for stat in self.calculate: # iterate through all stats that should be calculated
             func = self.statistics[stat]
             #print 'func', func
@@ -775,7 +812,7 @@ def make_thing():
     try:
         import new_lj_thellier_gui_spd as tgs
         gui = tgs.Arai_GUI('/magic_measurements.txt', main_dir)
-        specimens = gui.Data.keys()
+        specimens = list(gui.Data.keys())
         thing = PintPars(gui.Data, '0238x6011044', 473., 623.)
         thing.calculate_all_statistics()
         #new_thing = PintPars(gui.Data, '0238x5721062', 100. + 273., 525. + 273.)
@@ -784,8 +821,8 @@ def make_thing():
         thing2 = PintPars(gui2.Data, '0335x1031411', 273., 743.)
         return thing, thing2
     except Exception as ex:
-        print 'could not make standard specimen objects'
-        print ex
+        print('could not make standard specimen objects')
+        print(ex)
 
 
 #thing2 = PintPars(gui.Data, specimens[0], 473., 623.)
