@@ -8,9 +8,10 @@ from matplotlib.figure import Figure
 import help_files.demag_interpretation_editor_help as dieh
 from pmagpy.demag_gui_utilities import *
 from pmagpy.Fit import *
+from pmagpy.pmag import get_version
 
 global CURRENT_VERSION, PMAGPY_DIRECTORY
-CURRENT_VERSION = "v.0.33"
+CURRENT_VERSION = get_version()
 PMAGPY_DIRECTORY = find_pmag_dir.get_pmag_dir()
 IMG_DIRECTORY = os.path.join(PMAGPY_DIRECTORY, 'dialogs', 'images')
 
@@ -26,20 +27,21 @@ class InterpretationEditorFrame(wx.Frame):
         self.GUI_RESOLUTION=self.parent.GUI_RESOLUTION
         #call init of super class
         default_style = wx.MINIMIZE_BOX | wx.MAXIMIZE_BOX | wx.RESIZE_BORDER | wx.SYSTEM_MENU | wx.CAPTION | wx.CLOSE_BOX | wx.CLIP_CHILDREN | wx.NO_FULL_REPAINT_ON_RESIZE | wx.WS_EX_CONTEXTHELP | wx.FRAME_EX_CONTEXTHELP
-        wx.Frame.__init__(self, self.parent, title="Interpretation Editor",style=default_style, size=(675*self.GUI_RESOLUTION,425*self.GUI_RESOLUTION))
+        wx.Frame.__init__(self, self.parent, title="Interpretation Editor version:%s"%CURRENT_VERSION,style=default_style, size=(675*self.GUI_RESOLUTION,425*self.GUI_RESOLUTION))
         self.Bind(wx.EVT_CLOSE, self.on_close_edit_window)
         #setup wx help provider class to give help messages
         provider = wx.SimpleHelpProvider()
-        wx.HelpProvider_Set(provider)
+        wx.HelpProvider.Set(provider)
         self.helper = wx.ContextHelp(doNow=False)
         #make the Panel
         self.panel = wx.Panel(self,-1,size=(700*self.GUI_RESOLUTION,450*self.GUI_RESOLUTION))
         #set icon
-        icon = wx.EmptyIcon()
-        icon_path = os.path.join(IMG_DIRECTORY, 'PmagPy.ico')
-        if os.path.exists(icon_path):
-            icon.CopyFromBitmap(wx.Bitmap(icon_path), wx.BITMAP_TYPE_ANY)
-            self.SetIcon(icon)
+        self.SetIcon(self.parent.icon)
+#        icon = wx.Icon()
+#        icon_path = os.path.join(IMG_DIRECTORY, 'PmagPy.ico')
+#        if os.path.exists(icon_path):
+#            icon.CopyFromBitmap(wx.Bitmap(icon_path), wx.BITMAP_TYPE_ANY)
+#            self.SetIcon(icon)
         self.specimens_list=self.parent.specimens
         self.current_fit_index = None
         self.search_query = ""
@@ -234,19 +236,19 @@ class InterpretationEditorFrame(wx.Frame):
 
         for parameter in ['mean_type','dec','inc','alpha95','K','R','n_lines','n_planes']:
             COMMAND="self.%s_window=wx.TextCtrl(self.panel,style=wx.TE_CENTER|wx.TE_READONLY,size=(100*self.GUI_RESOLUTION,25))"%parameter
-            exec COMMAND
+            exec(COMMAND)
             COMMAND="self.%s_window.SetBackgroundColour(wx.WHITE)"%parameter
-            exec COMMAND
+            exec(COMMAND)
             COMMAND="self.%s_window.SetFont(font2)"%parameter
-            exec COMMAND
+            exec(COMMAND)
             COMMAND="self.%s_outer_window = wx.GridSizer(1,2,5*self.GUI_RESOLUTION,15*self.GUI_RESOLUTION)"%parameter
-            exec COMMAND
+            exec(COMMAND)
             COMMAND="""self.%s_outer_window.AddMany([
                     (wx.StaticText(self.panel,label='%s',style=wx.TE_CENTER),wx.EXPAND),
                     (self.%s_window, wx.EXPAND)])"""%(parameter,parameter,parameter)
-            exec COMMAND
+            exec(COMMAND)
             COMMAND="self.stats_sizer.Add(self.%s_outer_window, 1, wx.ALIGN_LEFT|wx.EXPAND, 0)"%parameter
-            exec COMMAND
+            exec(COMMAND)
 
         self.switch_stats_button = wx.SpinButton(self.panel, id=wx.ID_ANY, style=wx.SP_HORIZONTAL|wx.SP_ARROW_KEYS|wx.SP_WRAP, name="change stats")
         self.Bind(wx.EVT_SPIN, self.on_select_stats_button,self.switch_stats_button)
@@ -301,7 +303,7 @@ class InterpretationEditorFrame(wx.Frame):
         m_save_high_level = submenu_save_plots.Append(-1, "&Save high level plot", "")
         self.Bind(wx.EVT_MENU, self.parent.on_save_high_level, m_save_high_level,"Eq")
 
-        m_new_sub_plots = menu_file.AppendMenu(-1, "&Save plot", submenu_save_plots)
+        m_new_sub_plots = menu_file.AppendSubMenu(submenu_save_plots, "&Save plot")
 
         menu_file.AppendSeparator()
         m_exit = menu_file.Append(-1, "E&xit\tCtrl-Q", "Exit")
@@ -319,7 +321,7 @@ class InterpretationEditorFrame(wx.Frame):
         m_import_criteria_file =  submenu_criteria.Append(-1, "&Import criteria file", "")
         self.Bind(wx.EVT_MENU, self.parent.on_menu_criteria_file, m_import_criteria_file)
 
-        m_new_sub = menu_Analysis.AppendMenu(-1, "Acceptance criteria", submenu_criteria)
+        m_new_sub = menu_Analysis.AppendSubMenu(submenu_criteria, "Acceptance criteria")
 
         m_import_LSQ = menu_Analysis.Append(-1, "&Import Interpretations from LSQ file\tCtrl-L", "")
         self.Bind(wx.EVT_MENU, self.parent.on_menu_read_from_LSQ, m_import_LSQ)
@@ -389,7 +391,7 @@ class InterpretationEditorFrame(wx.Frame):
             m_tilt = menu_coordinates.Append(-1, "&Tilt-Corrected Coordinates\tCtrl-T", "")
             self.Bind(wx.EVT_MENU, self.parent.on_menu_change_tilt_coord, m_tilt)
 
-        m_coords = menu_edit.AppendMenu(-1, "&Coordinate Systems", menu_coordinates)
+        m_coords = menu_edit.AppendSubMenu(menu_coordinates, "&Coordinate Systems")
 
         #--------------------------------------------------------------------
 
@@ -454,9 +456,9 @@ class InterpretationEditorFrame(wx.Frame):
             spars = fit.get('specimen')
             fmin = fit.tmin
             fmax = fit.tmax
-            if 'specimen_n' in spars.keys(): n = str(spars['specimen_n'])
+            if 'specimen_n' in list(spars.keys()): n = str(spars['specimen_n'])
             else: n = 'No Data'
-            if 'calculation_type' in spars.keys(): ftype = spars['calculation_type']
+            if 'calculation_type' in list(spars.keys()): ftype = spars['calculation_type']
             else: ftype = 'No Data'
             dec = 'No Data'
             inc = 'No Data'
@@ -466,27 +468,27 @@ class InterpretationEditorFrame(wx.Frame):
             sk = 'No Data'
             sr2 = 'No Data'
         else:
-            if 'measurement_step_min' in pars.keys(): fmin = str(fit.tmin)
+            if 'measurement_step_min' in list(pars.keys()): fmin = str(fit.tmin)
             else: fmin = "N/A"
-            if 'measurement_step_max' in pars.keys(): fmax = str(fit.tmax)
+            if 'measurement_step_max' in list(pars.keys()): fmax = str(fit.tmax)
             else: fmax = "N/A"
-            if 'specimen_n' in pars.keys(): n = str(pars['specimen_n'])
+            if 'specimen_n' in list(pars.keys()): n = str(pars['specimen_n'])
             else: n = "N/A"
-            if 'calculation_type' in pars.keys(): ftype = pars['calculation_type']
+            if 'calculation_type' in list(pars.keys()): ftype = pars['calculation_type']
             else: ftype = "N/A"
-            if 'specimen_dec' in pars.keys(): dec = "%.1f"%pars['specimen_dec']
+            if 'specimen_dec' in list(pars.keys()): dec = "%.1f"%pars['specimen_dec']
             else: dec = "N/A"
-            if 'specimen_inc' in pars.keys(): inc = "%.1f"%pars['specimen_inc']
+            if 'specimen_inc' in list(pars.keys()): inc = "%.1f"%pars['specimen_inc']
             else: inc = "N/A"
-            if 'specimen_mad' in pars.keys(): mad = "%.1f"%pars['specimen_mad']
+            if 'specimen_mad' in list(pars.keys()): mad = "%.1f"%pars['specimen_mad']
             else: mad = "N/A"
-            if 'specimen_dang' in pars.keys(): dang = "%.1f"%pars['specimen_dang']
+            if 'specimen_dang' in list(pars.keys()): dang = "%.1f"%pars['specimen_dang']
             else: dang = "N/A"
-            if 'specimen_alpha95' in pars.keys(): a95 = "%.1f"%pars['specimen_alpha95']
+            if 'specimen_alpha95' in list(pars.keys()): a95 = "%.1f"%pars['specimen_alpha95']
             else: a95 = "N/A"
-            if 'specimen_k' in pars.keys(): sk = "%.1f"%pars['specimen_k']
+            if 'specimen_k' in list(pars.keys()): sk = "%.1f"%pars['specimen_k']
             else: sk = "N/A"
-            if 'specimen_r' in pars.keys(): sr2 = "%.1f"%pars['specimen_r']
+            if 'specimen_r' in list(pars.keys()): sr2 = "%.1f"%pars['specimen_r']
             else: sr2 = "N/A"
 
         if self.search_query != "":
@@ -502,19 +504,19 @@ class InterpretationEditorFrame(wx.Frame):
 
         if i < self.logger.GetItemCount():
             self.logger.DeleteItem(i)
-        self.logger.InsertStringItem(i, str(specimen))
-        self.logger.SetStringItem(i, 1, name)
-        self.logger.SetStringItem(i, 2, fmin)
-        self.logger.SetStringItem(i, 3, fmax)
-        self.logger.SetStringItem(i, 4, n)
-        self.logger.SetStringItem(i, 5, ftype)
-        self.logger.SetStringItem(i, 6, dec)
-        self.logger.SetStringItem(i, 7, inc)
-        self.logger.SetStringItem(i, 8, mad)
-        self.logger.SetStringItem(i, 9, dang)
-        self.logger.SetStringItem(i, 10, a95)
-        self.logger.SetStringItem(i, 11, sk)
-        self.logger.SetStringItem(i, 12, sr2)
+        self.logger.InsertItem(i, str(specimen))
+        self.logger.SetItem(i, 1, name)
+        self.logger.SetItem(i, 2, fmin)
+        self.logger.SetItem(i, 3, fmax)
+        self.logger.SetItem(i, 4, n)
+        self.logger.SetItem(i, 5, ftype)
+        self.logger.SetItem(i, 6, dec)
+        self.logger.SetItem(i, 7, inc)
+        self.logger.SetItem(i, 8, mad)
+        self.logger.SetItem(i, 9, dang)
+        self.logger.SetItem(i, 10, a95)
+        self.logger.SetItem(i, 11, sk)
+        self.logger.SetItem(i, 12, sr2)
         self.logger.SetItemBackgroundColour(i,"WHITE")
         a,b = False,False
         if fit in self.parent.bad_fits:
@@ -542,7 +544,7 @@ class InterpretationEditorFrame(wx.Frame):
         @param: new_fit -> fit object to highlight as selected
         """
         if len(self.fit_list)==0: return
-        if self.search_query and self.parent.current_fit not in map(lambda x: x[0], self.fit_list): return
+        if self.search_query and self.parent.current_fit not in [x[0] for x in self.fit_list]: return
         if self.current_fit_index == None:
             if not self.parent.current_fit: return
             for i,(fit,specimen) in enumerate(self.fit_list):
@@ -557,7 +559,7 @@ class InterpretationEditorFrame(wx.Frame):
         elif type(new_fit) is int:
             i = new_fit
         elif new_fit != None:
-            print('cannot select fit of type: ' + str(type(new_fit)))
+            print(('cannot select fit of type: ' + str(type(new_fit))))
         if self.current_fit_index != None and \
         len(self.fit_list) > 0 and \
         self.fit_list[self.current_fit_index][0] in self.parent.bad_fits:
@@ -648,7 +650,7 @@ class InterpretationEditorFrame(wx.Frame):
                         self.parent.user_warning('invalid hex color must be of form #0F0F0F');return
                 color_val = color_list[1]
             elif '(' in color_list[1] and ')' in color_list[1]:
-                color_val = map(eval, tuple(color_list[1].strip('( )').split(',')))
+                color_val = list(map(eval, tuple(color_list[1].strip('( )').split(','))))
                 for val in color_val:
                     if val > 1 or val < 0: self.parent.user_warning("invalid RGB sequence"); return
             else: self.parent.user_warning("colors must be given as a valid hex color or rgb tuple"); return
@@ -723,7 +725,7 @@ class InterpretationEditorFrame(wx.Frame):
             self.parent.level_names.SetStringSelection(high_level_name)
             self.parent.onSelect_level_name(event,True)
 
-        self.specimens_list.sort(cmp=specimens_comparator)
+        self.specimens_list.sort(key=spec_key_func)
         self.update_editor()
 
     def on_select_mean_type_box(self, event):
@@ -797,7 +799,7 @@ class InterpretationEditorFrame(wx.Frame):
 
         if not new_name:
             next_fit = str(len(self.parent.pmag_results_data['specimens'][specimen]) + 1)
-            while ("Fit " + next_fit) in map(lambda x: x.name, self.parent.pmag_results_data['specimens'][specimen]):
+            while ("Fit " + next_fit) in [x.name for x in self.parent.pmag_results_data['specimens'][specimen]]:
                 next_fit = str(int(next_fit) + 1)
             new_name = ("Fit " + next_fit)
         if not new_color:
@@ -807,11 +809,11 @@ class InterpretationEditorFrame(wx.Frame):
         if not new_tmin: new_tmin = None
         if not new_tmax: new_tmax = None
 
-        if new_name in map(lambda x: x.name, self.parent.pmag_results_data['specimens'][specimen]):
-            print('-E- interpretation called ' + new_name + ' already exsists for specimen ' + specimen)
+        if new_name in [x.name for x in self.parent.pmag_results_data['specimens'][specimen]]:
+            print(('-E- interpretation called ' + new_name + ' already exsists for specimen ' + specimen))
             return
 
-        self.parent.add_fit(specimen, new_name, new_tmin, new_tmax, color=new_color)
+        self.parent.add_fit(specimen, new_name, new_tmin, new_tmax, color=new_color,suppress_warnings=True)
 
     def delete_highlighted_fits(self, event):
         """
@@ -826,7 +828,7 @@ class InterpretationEditorFrame(wx.Frame):
             if next_i == -1:
                 break
             deleted_items.append(next_i)
-        deleted_items.sort(cmp=lambda x,y: y - x)
+        deleted_items.sort(reverse=True)
         for item in deleted_items:
             self.delete_entry(index=item)
         self.parent.update_selection()
@@ -847,7 +849,7 @@ class InterpretationEditorFrame(wx.Frame):
 
         if index == self.current_fit_index: self.current_fit_index = None
         if fit not in self.parent.pmag_results_data['specimens'][specimen]:
-            print("cannot remove item (entry #: " + str(index) + ") as it doesn't exist, this is a dumb bug contact devs")
+            print(("cannot remove item (entry #: " + str(index) + ") as it doesn't exist, this is a dumb bug contact devs"))
             self.logger.DeleteItem(index)
             return
         self.parent.pmag_results_data['specimens'][specimen].remove(fit)
@@ -874,7 +876,7 @@ class InterpretationEditorFrame(wx.Frame):
             specimen = self.fit_list[next_i][1]
             fit = self.fit_list[next_i][0]
             if new_name:
-                if new_name not in map(lambda x: x.name, self.parent.pmag_results_data['specimens'][specimen]): fit.name = new_name
+                if new_name not in [x.name for x in self.parent.pmag_results_data['specimens'][specimen]]: fit.name = new_name
             if new_color:
                 fit.color = self.color_dict[new_color]
             #testing
@@ -973,17 +975,17 @@ class InterpretationEditorFrame(wx.Frame):
         ydata_org = self.parent.high_EA_ydata
         data_corrected = self.eqarea.transData.transform(vstack([xdata_org,ydata_org]).T)
         xdata,ydata = data_corrected.T
-        xdata = map(float,xdata)
-        ydata = map(float,ydata)
+        xdata = list(map(float,xdata))
+        ydata = list(map(float,ydata))
         e = 4e0
 
         if self.high_EA_setting == "Zoom":
-            self.canvas.SetCursor(wx.StockCursor(wx.CURSOR_CROSS))
+            self.canvas.SetCursor(wx.Cursor(wx.CURSOR_CROSS))
         else:
-            self.canvas.SetCursor(wx.StockCursor(wx.CURSOR_ARROW))
+            self.canvas.SetCursor(wx.Cursor(wx.CURSOR_ARROW))
         for i,(x,y) in enumerate(zip(xdata,ydata)):
             if 0 < sqrt((x-xpick_data)**2. + (y-ypick_data)**2.) < e:
-                self.canvas.SetCursor(wx.StockCursor(wx.CURSOR_HAND))
+                self.canvas.SetCursor(wx.Cursor(wx.CURSOR_HAND))
                 break
         event.Skip()
 
